@@ -1,8 +1,10 @@
 package Perl::Critic::Policy::Moose::ProhibitDESTROYMethod;
-$Perl::Critic::Policy::Moose::ProhibitDESTROYMethod::VERSION = '1.01';
+
 use strict;
 use warnings;
 
+our $VERSION = '1.02';
+
 use Readonly ();
 
 use Perl::Critic::Utils qw< :booleans :severities $EMPTY >;
@@ -18,10 +20,9 @@ sub supported_parameters {
         {
             name => 'equivalent_modules',
             description =>
-                q<The additional modules to treat as equivalent to "Moose".>,
-            default_string             => $EMPTY,
+                q<The additional modules to treat as equivalent to "Moose", "Moose::Role", or "MooseX::Role::Parameterized".>,
             behavior                   => 'string list',
-            list_always_present_values => [qw< Moose Moose::Role >],
+            list_always_present_values => [qw< Moose Moose::Role MooseX::Role::Parameterized >],
         },
     );
 }
@@ -94,7 +95,7 @@ Perl::Critic::Policy::Moose::ProhibitDESTROYMethod - Use DEMOLISH instead of DES
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 DESCRIPTION
 
@@ -134,13 +135,13 @@ say, you were doing something with L<Moose::Exporter>. For example, if you
 were to have this in your F<.perlcriticrc> file:
 
     [Moose::ProhibitDESTROYMethod]
-    equivalent_modules = Foo Bar
+    equivalent_modules = MyCompany::Moose MooseX::NewThing
 
 then the following code would result in a violation:
 
     package Baz;
 
-    use Bar;
+    use MyCompany::Moose;
 
     sub DESTROY {
         ...
