@@ -1,8 +1,10 @@
 package Perl::Critic::Policy::Moose::RequireMakeImmutable;
-$Perl::Critic::Policy::Moose::RequireMakeImmutable::VERSION = '1.01';
+
 use strict;
 use warnings;
 
+our $VERSION = '1.02';
+
 use Readonly ();
 
 use Perl::Critic::Utils qw< :booleans :severities >;
@@ -14,7 +16,19 @@ Readonly::Scalar my $DESCRIPTION => 'No call was made to make_immutable().';
 Readonly::Scalar my $EXPLANATION =>
     q<Moose can't optimize itself if classes remain mutable.>;
 
-sub supported_parameters { return (); }
+sub supported_parameters {
+    return (
+        {
+            name            => 'equivalent_modules',
+            description     =>
+                q<The additional modules to treat as equivalent to "Moose".>,
+            default_string  => 'Moose',
+            behavior        => 'string list',
+            list_always_present_values => [qw< Moose >],
+        },
+    );
+}
+
 sub default_severity     { return $SEVERITY_MEDIUM; }
 sub default_themes       { return qw( moose performance ); }
 sub applies_to           { return 'PPI::Document' }
@@ -22,19 +36,17 @@ sub applies_to           { return 'PPI::Document' }
 sub prepare_to_scan_document {
     my ( $self, $document ) = @_;
 
-    # Tech debt: duplicate code.
-    return $document->find_any(
-        sub {
-            my ( undef, $element ) = @_;
+    return $self->_is_interesting_document($document);
+}
 
-            return $FALSE if not $element->isa('PPI::Statement::Include');
-            return $FALSE if not $element->type() eq 'use';
+sub _is_interesting_document {
+    my ( $self, $document ) = @_;
 
-            my $module = $element->module();
-            return $FALSE if not $module;
-            return $module eq 'Moose';
-        }
-    );
+    foreach my $module ( keys %{ $self->{_equivalent_modules} } ) {
+        return $TRUE if $document->uses_module($module);
+    }
+
+    return $FALSE;
 }
 
 sub violates {
@@ -98,7 +110,7 @@ Perl::Critic::Policy::Moose::RequireMakeImmutable - Ensure that you've made your
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 DESCRIPTION
 
@@ -115,7 +127,25 @@ This policy is part of L<Perl::Critic::Moose>.
 
 =head1 CONFIGURATION
 
-This policy has no configuration options beyond the standard ones.
+There is a single option, C<equivalent_modules>. This allows you to specify
+modules that should be treated the same as L<Moose> and L<Moose::Role>, if,
+say, you were doing something with L<Moose::Exporter>. For example, if you
+were to have this in your F<.perlcriticrc> file:
+
+    [Moose::RequireMakeImmutable]
+    equivalent_modules = MyCompany::Moose MooseX::NewThing
+
+then the following code would result in a violation:
+
+    package Baz;
+
+    use MyCompany::Moose;
+
+    sub new {
+        ...
+    }
+
+    # no make_immutable call
 
 =head1 AUTHORS
 
